// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.sessiondemo;

/**
 **  Implementation of the OMG IDL3 <tt>Client</tt> component type.
 **/
public class ClientImpl
extends Client_MainSegBase
implements java.awt.event.ActionListener, java.io.Serializable
{
    // client
    private javax.swing.JFrame _frame;
    private javax.swing.JList _product_list;
    private javax.swing.JList _caddie_list;
    private Server _server;
    private org.omg.Components.Cookie _i_server_ck;

    // default constructor
    public
    ClientImpl()
    {
        // client
        _frame = null;
        _product_list = null;
        _caddie_list = null;
        _server = null;
        _i_server_ck = null;
    }

    //
    //  overriden operations
    //

    final public void
    configuration_complete()
    throws org.omg.Components.InvalidConfiguration
    {
        // create a GUI
        // NORTH: panel with buttons "enter" and "leave"
        javax.swing.JPanel npanel = new javax.swing.JPanel(new java.awt.BorderLayout());
        javax.swing.JButton enterb = new javax.swing.JButton("Enter");
        enterb.setActionCommand("enter");
        enterb.addActionListener(this);
        javax.swing.JButton leaveb = new javax.swing.JButton("Leave");
        leaveb.setActionCommand("leave");
        leaveb.addActionListener(this);
        npanel.add(enterb, java.awt.BorderLayout.WEST);
        npanel.add(leaveb, java.awt.BorderLayout.EAST);

        // SOUTH: box with products and caddie panels
        //    EAST: panel with product list and button "Purchase"
        javax.swing.JPanel bnpanel = new javax.swing.JPanel(new java.awt.BorderLayout());
        _product_list = new javax.swing.JList();
        javax.swing.JButton purchaseb = new javax.swing.JButton("Purchase");
        purchaseb.setActionCommand("purchase");
        purchaseb.addActionListener(this);
        bnpanel.add(_product_list, java.awt.BorderLayout.NORTH);
        bnpanel.add(purchaseb, java.awt.BorderLayout.SOUTH);

        //    WEST: panel with caddie list and button "Remove"
        javax.swing.JPanel bspanel = new javax.swing.JPanel(new java.awt.BorderLayout());
        _caddie_list = new javax.swing.JList();
        javax.swing.JButton removeb = new javax.swing.JButton("Remove");
        removeb.setActionCommand("remove");
        removeb.addActionListener(this);
        bspanel.add(_caddie_list, java.awt.BorderLayout.NORTH);
        bspanel.add(removeb, java.awt.BorderLayout.SOUTH);

        javax.swing.JPanel spanel = new javax.swing.JPanel(new java.awt.BorderLayout());
        spanel.add(bnpanel, java.awt.BorderLayout.EAST);
        spanel.add(bspanel, java.awt.BorderLayout.WEST);

        // MAIN panel
        javax.swing.JPanel panel = new javax.swing.JPanel(new java.awt.BorderLayout());
        panel.add(npanel, java.awt.BorderLayout.NORTH);
        panel.add(spanel, java.awt.BorderLayout.SOUTH);
        _frame = new javax.swing.JFrame("Client GUI");
        _frame.getContentPane().add(panel);
        _frame.pack();
        _frame.show();
    }

    //
    //  IDL:objectweb.org/ccm/sessiondemo/Client:1.0
    //

    // 
    //  java.awt.event.ActionListener
    //

    final public void
    actionPerformed(java.awt.event.ActionEvent e)
    {
        String cmd = e.getActionCommand();

        if (cmd.equals("enter")) {
            // create a new Server component and connect it
            try {
                org.omg.Components.LocalReceptacles lrecs = getCCM2Context().get_receptacles();
                org.omg.CORBA.Object obj = lrecs.get_connections("server_home")[0].ref();
                ServerHome shome = ServerHomeHelper.narrow(obj);
                // NOTE: typed operation
                // ServerHome shome = get_connection_server_home();

                _server = shome.create();
                _server.configuration_complete();

                _i_server_ck = lrecs.connect("i_server", _server.provide_i_server());
                // NOTE: typed operation
                // connect_i_server(_server.provide_i_server());

                // obtain product list and display
                obj = lrecs.get_connections("i_server")[0].ref();
                IServer iserver = IServerHelper.narrow(obj);
                Product[] products = iserver.list_products();
                // NOTE: typed operation
                // Product[] products = get_connection_i_server().list_products();

                String[] pids = new String[products.length];
                for (int i=0;i<products.length;i++) {
                    pids[i] = products[i].id;
                }

                _product_list.setListData(pids);
                return ;
            } catch (Exception ex) {
                ex.printStackTrace();
                return;
            }
        }

        if (cmd.equals("leave")) {
            // remove everything from caddie
            try {
                org.omg.Components.LocalReceptacles lrecs = getCCM2Context().get_receptacles();
                javax.swing.ListModel lmodel = _caddie_list.getModel();
                String[] ids = new String[lmodel.getSize()];
                for (int i=0;i<ids.length;i++) {
                    ids[i] = (String)lmodel.getElementAt(i);
                }

                org.omg.CORBA.Object obj = lrecs.get_connections("i_server")[0].ref();
                IServer iserver = IServerHelper.narrow(obj);
                // NOTE: typed operation
                // IServer iserver = get_connection_i_server();
                iserver.remove_products(ids);

                // disconnect
                lrecs.disconnect(_i_server_ck);
                // NOTE: typed operation
                // disconnect_i_server();

                // clear list
                _product_list.setListData(new Object[0]);
                _caddie_list.setListData(new Object[0]);

                // destroy component
                obj = lrecs.get_connections("server_home")[0].ref();
                ServerHome shome = ServerHomeHelper.narrow(obj);
                shome.remove_component(_server);
                return ;
            } catch (Exception ex) {
                ex.printStackTrace();
                return ;
            }
        }

        if (cmd.equals("purchase")) {
            // obtain the purchased ids
            try {
                org.omg.Components.LocalReceptacles lrecs = getCCM2Context().get_receptacles();
                Object[] objs = _product_list.getSelectedValues();
                String[] ids = new String[objs.length];
                for (int i=0;i<objs.length;i++) {
                    ids[i] = (String)objs[i];
                }

                // purchase
                org.omg.CORBA.Object obj = lrecs.get_connections("i_server")[0].ref();
                IServer iserver = IServerHelper.narrow(obj);
                // NOTE: typed operation
                // IServer iserver = get_connection_i_server();
                iserver.purchase_products(ids);

                // update caddie and display
                Product[] products = iserver.view_caddie();
                String[] pids = new String[products.length];
                for (int i=0;i<products.length;i++) {
                    pids[i] = products[i].id;
                }

                _product_list.clearSelection();
                _caddie_list.setListData(pids);
                return ;
            } catch (Exception ex) {
                ex.printStackTrace();
                return ;
            }
        }

        if (cmd.equals("remove")) {
            // obtain the removed ids
            try {
                org.omg.Components.LocalReceptacles lrecs = getCCM2Context().get_receptacles();
                Object[] objs = _caddie_list.getSelectedValues();
                String[] ids = new String[objs.length];
                for (int i=0;i<objs.length;i++) {
                    ids[i] = (String)objs[i];
                }

                // remove
                org.omg.CORBA.Object obj = lrecs.get_connections("i_server")[0].ref();
                IServer iserver = IServerHelper.narrow(obj);
                // NOTE: typed operation
                // IServer iserver = get_connection_i_server();
                iserver.remove_products(ids);

                // update caddie and display
                Product[] products = iserver.view_caddie();
                String[] pids = new String[products.length];
                for (int i=0;i<products.length;i++) {
                    pids[i] = products[i].id;
                }

                _caddie_list.clearSelection();
                _caddie_list.setListData(pids);
                return ;
            } catch (Exception ex) {
                ex.printStackTrace();
                return ;
            }
        }
    }
}
