// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.logdemo;

/**
 **  This is the ECM-unaware (and CCM standard) implementation of the OMG IDL3
 **  <tt>Client</tt> component type.
 **/
public class ClientImpl
extends Client_MainSegBase
implements java.io.Serializable, java.awt.event.ActionListener
{
    // client
    private String _name;
    private javax.swing.JFrame _frame;
    private javax.swing.JTextField _text;

    // default constructor
    public
    ClientImpl()
    {
        // client
        _name = null;
        _frame = null;
        _text = null;
    }

    //
    //  overriden operations
    //

    final public void
    configuration_complete()
    throws org.omg.Components.InvalidConfiguration
    {
        // create a GUI
        // NORTH: text field for user inputs
        _text = new javax.swing.JTextField("", 1);

        // CENTER: send button
        javax.swing.JButton printb = new javax.swing.JButton("Send");
        printb.addActionListener(this);

        // MAIN panel
        javax.swing.JPanel panel = new javax.swing.JPanel(new java.awt.BorderLayout());
        panel.add(new javax.swing.JScrollPane(_text), java.awt.BorderLayout.NORTH);
        panel.add(printb, java.awt.BorderLayout.CENTER);
        _frame = new javax.swing.JFrame(_name+" GUI");
        _frame.setSize(400, 300);
        _frame.getContentPane().add(panel);
        _frame.pack();
        _frame.show();
    }
		
    //
    //  IDL:objectweb.org/ecm/logdemo/Client:1.0
    //

    final public void
    name(String n)
    {
        _name = n;

        if (_frame!=null) {
            _frame.setTitle(_name+" GUI");
        }
    }

    final public String
    name()
    {
        return _name;
    }

    //
    // java.awt.event.ActionListener
    //

    final public void
    actionPerformed(java.awt.event.ActionEvent e)
    {
        try {
            // build message
            Message msg = new Message();
            msg.header = _name;
            msg.content = _text.getText();

            // build async message
            AsyncMessage amsg = new AsyncMessageImpl(msg);

            // push to emitter
            org.omg.Components.LocalEvents levts = getCCM2Context().get_events();
            int chid = levts.get_channel("async_display");
            levts.push(amsg, chid);

            // send to connected Display
            org.omg.Components.LocalReceptacles lrecs = getCCM2Context().get_receptacles();
            org.omg.CORBA.Object obj = lrecs.get_connections("display")[0].ref();
            SynchronousDisplay dis = SynchronousDisplayHelper.narrow(obj);
            // check if available.
            if(dis!=null) {
                dis.print(msg);
            }
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }
}
