// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Default implementation for the OMG IDL <tt>Components::Cookie</tt> valuetype.</p>
 **/
public class CookieImpl
extends org.omg.Components.Cookie
{
    transient private int _channel_id;
    transient private String _name;

    // default constructor
    public
    CookieImpl()
    {
        // cookie
        cookieValue = null;
    }

    // constructor with initial value
    public
    CookieImpl(byte[] val)
    {
        // cookie
        cookieValue = val;
    }

    // constructor for event port cookie
    public 
    CookieImpl(int chid)
    {
        // cookie
        _channel_id = chid;
        _name = null;

        // compute value: <channel_id>:<random>
        double d = Math.random();
        String sval = Integer.toString(_channel_id)+":"+Double.toString(d);
        cookieValue = sval.getBytes();
    }

    // constructor for receptacle cookie
    public 
    CookieImpl(String n)
    {
        // cookie
        _channel_id = -1;
        _name = n;

        // compute value: <name>:<random>
        double d = Math.random();
        String sval = _name+":"+Double.toString(d);
        cookieValue = sval.getBytes();
    }

    //
    //  internal operations
    //

    final protected byte[]
    getCookieValue()
    {
        return cookieValue;
    }

    final protected void
    initialize()
    {
        String sval = new String(cookieValue);
        int idx = sval.indexOf(':');
        _name = sval.substring(0, idx);
        try {
            _channel_id = Integer.parseInt(_name);
        } catch (java.lang.NumberFormatException ex) {
            // ignore
        }
    }

    //
    //  public operations
    //

    final public int
    getChannelId()
    {
        if (_channel_id==-1) {
            initialize();
        }

        return _channel_id;
    }

    final public String
    getName()
    {
        if (_name==null) {
            initialize();
        }

        return _name;
    }

    //
    //  java.lang.Object
    //

    final public boolean
    equals(Object obj)
    {
        // check if CookieImpl
        if (!(obj instanceof CookieImpl)) {
            return false;
        }

        // we are forced to cast to CookieImpl
        CookieImpl ck = (CookieImpl)obj;
        if (java.util.Arrays.equals(cookieValue, ck.getCookieValue())) {
            return true;
        } else {
            return false;
        }
    }
}
