// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.logdemo;

/**
 **  This is the ECM-aware implementation of the OMG IDL3 <tt>Server</tt> component type
 **  which uses the simple log service.
 **/
public class ServerWithLogImpl
extends Server_MainSegBase
implements java.io.Serializable,
           org.coach.ECM.ECMExecutor,
           org.objectweb.ccm.logservice.LogCallback
{
    // server
    private String _name;
    private javax.swing.JFrame _frame;
    private javax.swing.JTextArea _text;

    public
    ServerWithLogImpl()
    {
        // server
        _name = null;
        _frame = null;
        _text = null;
    }

    //
    //  overriden operations
    //

    final public void
    configuration_complete()
    throws org.omg.Components.InvalidConfiguration
    {
        // create a GUI
        // CENTER: text field to display client inputs
        _text = new javax.swing.JTextArea(40, 20);
        _text.setEditable(false);

        // MAIN panel
        javax.swing.JPanel panel = new javax.swing.JPanel(new java.awt.BorderLayout());
        panel.add(new javax.swing.JScrollPane(_text), java.awt.BorderLayout.CENTER);
        _frame = new javax.swing.JFrame(_name + " GUI");
        _frame.setSize(400, 300);
        _frame.getContentPane().add(panel);
        _frame.pack();
        _frame.show();
    }

    //
    //  IDL:omg.org/Components/SessionComponent:1.0
    //

    final public void
    ccm_activate()
    throws org.omg.Components.CCMException
    {
        // show the frame if hidden
        if ((_frame!=null) && (!_frame.isShowing())){
            _frame.show();
        }
    }

    final public void
    ccm_passivate()
    throws org.omg.Components.CCMException
    {
        // hide the frame and clear the text field
        _frame.hide();
        _text.setText(null);
    }

    final public void
    ccm_remove()
    throws org.omg.Components.CCMException
    {
        // Release the associated frame.
        _frame.dispose();
        _frame = null;
    }

    //
    //  IDL:coach.org/ECM/ECMExecutor:1.0
    //

    final public org.omg.CORBA.Object
    get_service_callback(String sid, String cid)
    throws org.coach.ECM.UnknownService,
           org.coach.ECM.UnknownServiceCallback
    {
        if (!sid.equals(org.objectweb.ccm.logservice.LOG_SERVICE_ID.value)) {
            throw new org.coach.ECM.UnknownService();
        }

        if (!cid.equals(org.objectweb.ccm.logservice.LOG_SERVICE_CALLBACK_ID.value)) {
            throw new org.coach.ECM.UnknownServiceCallback();
        }

        return this;
    }

    //
    //  IDL:objectweb.org/ccm/logservice/LogCallback:1.0
    //

    final public String
    get_identity()
    {
        return "Server:"+name();
    }

    //
    //  IDL:objectweb.org/ccm/logdemo/CCM_Display:1.0
    //

    final public void
    print(Message msg)
    {
        // add content to the text field
        _text.append("["+msg.header+"] "+msg.content + "\n");

        // use the log service internal interface to send a log event.
        try {
            // get ECMContext 
            org.coach.ECM.ECMContext ctx = getECMContext();
            org.objectweb.ccm.logservice.LogInternal internal = null;

            // may raise UnknownService or UnknownServiceInternal exceptions if the service is not installed
            // or if the particular internal was not registered by the service
            Object obj = ctx.get_service_internal(org.objectweb.ccm.logservice.LOG_SERVICE_ID.value,
                                                  org.objectweb.ccm.logservice.LOG_SERVICE_INTERNAL_ID.value);

            // should not fail
            internal = (org.objectweb.ccm.logservice.LogInternal)obj;

            // build a log event with INFO_LEVEL
            org.objectweb.corba.logservice.LogEvent evt = new org.objectweb.corba.logservice.LogEvent();
            evt.level = org.objectweb.corba.logservice.DEBUG_LEVEL.value;
            org.objectweb.corba.logservice.MessageContent content = new org.objectweb.corba.logservice.MessageContent();
            java.util.Calendar cal = java.util.Calendar.getInstance();
            content.timestamp = java.lang.Long.toString(cal.getTimeInMillis());
            content.interception_point = "";
            content.operation_name = "print";
            content.sender_id = "";
            content.receiver_id = get_identity();
            content.data = "["+msg.header+"] "+msg.content;
            evt.message = content;
            // send
            internal.log_event(evt);
        } catch (Exception ex) {
            ex.printStackTrace();
        }
    }

    //
    //  IDL:objectweb.org/ccm/logdemo/Server:1.0
    //

    final public void
    name(String n)
    {
        _name = n;

        if (_frame!=null) {
            _frame.setTitle(_name+" GUI");
        }
    }

    final public String
    name()
    {
        return _name;
    }
}


