// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Default implementation of the <tt>SlotFactory</tt> interface.</p>
 **/
public class SlotFactory
{
    //
    private java.util.Hashtable _values;  // (thread id, hashtable of values)
    private SlotImpl[] _slots;  // index = ECA::SlotId, value = SlotImpl)
    private int _default_length;
    private int _default_increment;
    private int _slot_number;

    // default constructor
    public
    SlotFactory()
    {
        _values = new java.util.Hashtable();

        _default_length = 10;
        _default_increment = 10;
        _slot_number = 0;
        _slots = new SlotImpl[_default_length];
    }

    // constructor with length and increment for the slot table
    public
    SlotFactory(int dl, int di)
    {
        _values = new java.util.Hashtable();

        _default_length = dl;
        _default_increment = di;
        _slot_number = 0;
        _slots = new SlotImpl[_default_length];
    }

    //
    //  internal operations
    //

    private void
    reallocateSlotTable()
    {
        SlotImpl[] ntable = new SlotImpl[_slots.length+_default_increment];

        // copy
        System.arraycopy(_slots, 0, ntable, 0, _slots.length);
        _slots = ntable;
    }

    private void
    setSlot(int sid, SlotImpl slot)
    {
        // check if size if ok
        if (sid>=_slots.length) {
            reallocateSlotTable();
        }

        _slots[sid] = slot;
    }

    //
    //  public operations
    //

    final public int
    allocateSlotId()
    {
        // set a null slot
        setSlot(_slot_number, null);

        //
        return _slot_number;
    }

    final public SlotImpl
    getSlot(int sid)
    {
        // check if the slot is already created
        if (_slots[sid]!=null) {
            return _slots[sid];
        }

        // create and store
        SlotImpl slot = new SlotImpl(_values, sid);
        _slots[sid] = slot;

        return slot;
    }
}
