@echo off
REM ==================================================================== 
REM
REM   ECM: The Extensible Container Model
REM   Copyright (C) 2004 THALES
REM   Contact: openccm-ecm@objectweb.org
REM
REM   This library is free software; you can redistribute it and/or
REM   modify it under the terms of the GNU Lesser General Public
REM   License as published by the Free Software Foundation; either
REM   version 2.1 of the License, or any later version.
REM
REM   This library is distributed in the hope that it will be useful,
REM   but WITHOUT ANY WARRANTY; without even the implied warranty of
REM   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
REM   Lesser General Public License for more details.
REM
REM   You should have received a copy of the GNU Lesser General Public
REM   License along with this library; if not, write to the Free Software
REM   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
REM   USA
REM
REM   Initial developer(s): Mathieu Vadet
REM   Initial funding: IST COACH European Project (IST-2001-34445)
REM                    http://www.ist-coach.org
REM
REM ==================================================================== 


REM
REM  Starts a server activator
REM

setlocal

goto begin

:usage
    echo usage: sa_start.bat [options]
    echo Starts a CCM ServerActivator.
    echo It also starts local CORBA CosNaming service and a CCM ExtendedComponentInstallation.
    echo --
    echo The following options are supported:
    echo   /h, /help     Print this message
    echo   /debug        Activate debug mode (optional)
    echo   /ns nsior     NS to use for registrations, default to NS_at_hostname NS (optional)
    echo   name          The logical name of the SA, SA_at_hostname by default (optional)
    echo                 NOTE: if name is set, then the ExtCI will use ExtCI_at_name as logical name, ExtCI_at_hostname otherwise,
    echo                       and the NS will use NS_at_name as logical name, NS_at_hostname otherwise
    exit /B 1

:begin
set debug=
set name=
set extci_name=
set ns_name=
set ns=
set args=
set jvmargs=

:parse_args
if not "%1"=="" (
    if "%1"=="/h" (
        goto usage
    ) else if "%1"=="/help" (
        goto usage
    ) else if "%1"=="/debug" (
        set debug=/debug
    ) else if "%1"=="/ns" (
        set ns=/ns %2
        shift
    ) else (
        set name=%1
        set extci_name=ExtCI_at_%1
        set ns_name=NS_at_%1
    ) 

    shift
    goto parse_args
)

REM check if name is set
if not defined name (
    if defined debug (
        echo WARNING: Will use default name for CCM ServerActivator.
    )

    hostname > %TEMP%\hostname.tmp
    for /f %%i in (%TEMP%\hostname.tmp) do (
        set name=SA_at_%%i
    )
    del %TEMP%\hostname.tmp 2> nul
)


REM start the NS
call @ECM.install.bin.dir@\ns_start.bat %debug% %ns_name%
if ERRORLEVEL 1 exit /B 1

REM obtain local NS IOR
call @ECM.install.bin.dir@\ns_ior.bat %debug% /url %ns_name% > %TEMP%\ns_ior.tmp
if ERRORLEVEL 1 exit /B 1

for /f %%i in (%TEMP%\ns_ior.tmp) do (
    set nsior=%%i
)
del %TEMP%\ns_ior.tmp 2> nul

REM add reference of local NS
set args=-ORBInitRef LocalNameService=%nsior%

REM check if a remote NS is set
if not defined ns (
    REM use local NS as remote NS
    set ns=/ns %nsior%
)

REM start an extended component installation
call @ECM.install.bin.dir@\extci_start.bat %debug% %ns% %extci_name%
if ERRORLEVEL 1 exit /B 1

REM obtain ExtCI IOR and set it as an initial ref
call @ECM.install.bin.dir@\extci_ior.bat %debug% /url %extci_name% > %TEMP%\extci_ior.tmp
if ERRORLEVEL 1 exit /B 1

for /f %%i in (%TEMP%\extci_ior.tmp) do (
    set args=-ORBInitRef ExtComponentInstallation=%%i %args%
)
del %TEMP%\extci_ior.tmp 2> nul

REM set "os.option.char" java property
set jvmargs="-Dos.option.str=/"

REM 
set jvmargs=-DECM.install.lib.dir=@ECM.install.lib.dir@ %jvmargs%
set jvmargs=-DECM.install.launcher.dir=@ECM.install.launcher.dir@ %jvmargs%

REM set code location and entrypt
set location=@ECM.install.lib.dir@\ccm_runtime_sa.jar
set entrypt=org.objectweb.ccm.runtime.ServerActivatorImpl.create_servant

REM delegate to corba_runtime_start script
call @ECM.install.bin.dir@\corba_runtime_start.bat /jvmargs "%jvmargs:"=%" /args "%args:"=%" /location %location% /entrypoint %entrypt% %ns% %debug% %name%

:eof
