// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>The <code>MainThread</code> interface is used to represent the main
 **  thread of a process. The purpose of this interface is to allow ORB
 **  instances to run in the main thread of the process. Indeed some ORB implementations
 **  may not work properly if they do not run in this particular thread.</p>
 **/
public interface MainThread
{
    /**
     **  Stop a running ORB. Stopping an ORB means that it will no longer have time slots
     **  for its execution. This does not mean that the ORB will be destroyed.
     **
     **  @param orb The ORB that shall be stopped.
     **/
    public void
    stopORB(org.omg.CORBA.ORB orb);

    /**
     **  Starts an ORB. Starting an ORB means that it will be provided with time slots
     **  for its execution.
     **
     **  @param orb The ORB that shall be started.
     **/
     public void
    runORB(org.omg.CORBA.ORB orb);

    /**
     **  Starts the main thread.
     **/
    public void
    startThread();
}
