// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>Single-threaded implementation of the <tt>MainThread</tt> interface. ORBs execute
 **  one after the other in a single thread. The implementation relies on the <tt>work_pending</tt>
 **  and <tt>perform_work</tt> operations of the ORB interface.</p>
 **
 **  @see org.objectweb.corba.runtime.MainThread MainThread
 **/
public class MultipleORBWorker
extends java.lang.Thread
implements MainThread 
{
    // MainThread
    private org.omg.CORBA.ORB[] _orbs;
    private Object _orbs_mutex;

    public
    MultipleORBWorker() 
    {
        _orbs = new org.omg.CORBA.ORB[0];
        _orbs_mutex = new Object();
    }

    //
    //  internal operations
    //

    private org.omg.CORBA.ORB[]
    getORBs()
    {
        synchronized(_orbs_mutex) {
            return _orbs;
        }
    }

    private void
    addORB(org.omg.CORBA.ORB orb)
    {
        synchronized(_orbs_mutex) {
            // copy
            org.omg.CORBA.ORB[] orbs = new org.omg.CORBA.ORB[_orbs.length+1];
            System.arraycopy(_orbs, 0, orbs, 0, _orbs.length);
            orbs[_orbs.length] = orb;

            // store
            _orbs = orbs;
        }
    }

    private void
    removeORB(org.omg.CORBA.ORB orb)
    {
        synchronized(_orbs_mutex) {
            // copy and remove
            org.omg.CORBA.ORB[] orbs = new org.omg.CORBA.ORB[_orbs.length-1];
            int j=0;
            for (int i=0;i<_orbs.length;i++) {
                if (_orbs[i]!=orb) {
                    orbs[j++] = _orbs[i];
                }
            }

            // store
            _orbs = orbs;
        }
    }

    //
    //  MainThread java interface
    //

    final public void
    stopORB(org.omg.CORBA.ORB orb)
    {
        removeORB(orb);
    }

    final public void
    runORB(org.omg.CORBA.ORB orb)
    {
        addORB(orb);
    }

    final public void
    startThread()
    {
        // start the thread
        start();
    }

    //
    //  Thread java interface
    //

    final public void
    run()
    {
        org.omg.CORBA.ORB[] orbs;
        // NOTE: we should have a boolean which can be set externally
        // to break this loop
        while (true) {
            orbs = getORBs(); 
            for (int i=0;i<orbs.length;i++) {
                if (orbs[i].work_pending()) {
                    orbs[i].perform_work();
                }
            }
        }
    }
}
