// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>The <tt>TheClassLoader</tt> class provides resources loading and class instantiation
 **  features. It relies on the launcher's <tt>XBootClassLoader</tt> class.</p>
 **/
public class TheClassLoader
{
    // 
    static private String _class_name = "TheClassLoader";
    static private org.objectweb.util.launcher.XBootClassLoader _xloader;

    //
    //  internal operations
    //

    static private void
    init()
    {
        _xloader = (org.objectweb.util.launcher.XBootClassLoader)Thread.currentThread().getContextClassLoader();
    }

    static private org.objectweb.util.launcher.XBootClassLoader
    getXLoader()
    {
        if (_xloader==null) {
            init();
        }

        return _xloader;
    }

    static private Object
    callStaticClassMethod(String entrypt,
                          Class[] argt,
                          Object[] argv)
    throws java.lang.ClassNotFoundException,
           java.lang.NoSuchMethodException,
           java.lang.reflect.InvocationTargetException,
           java.lang.IllegalAccessException
    {
        // extract the class name and the method name.
        int idx = entrypt.lastIndexOf('.');
        java.lang.String class_name = entrypt.substring(0, idx);
        java.lang.String method_name = entrypt.substring(idx+1);

        //String opname = "callStaticClassMethod";
        //String msg = "class name is: "+class_name+" ; method name is: "+method_name;
        //TheLogger.debug(_class_name, opname, msg);

        // Search the class using forName
        Class the_class = Class.forName(class_name);

        // Search the static method.
        java.lang.reflect.Method the_method = the_class.getMethod(method_name, argt);

        // Call the static method.
        Object result = the_method.invoke(null, argv);

        // Return the result.
        return result;
    }

    //
    //  static operations
    //

    static public void
    addResource(String path)
    {
        final String opname = "addResource";
        // create URL
        // NOTE: path is local (mandatory)
        String url_str = path;
        if (!url_str.startsWith("file:")) {
            url_str = "file:"+url_str;
        }

        java.net.URL url = null;
        try {
            url = new java.net.URL(url_str);
        } catch (java.net.MalformedURLException ex) {
            // NOTE: TODO: should be reported as an exception as it will certainly lead
            // to further errors
            TheLogger.error(_class_name, opname, "FAILED (wrong URL format)", ex);
        }

        // add URL to the parent loader
        final String msg = "Adding URL: "+url.toString();
        TheLogger.debug(_class_name, opname, msg);
        getXLoader().addURL(url);
    }

    static public Object
    newInstance(String entrypt)
    {
        return newInstance(entrypt, new Class[0], new Object[0]);
    }

    static public Object
    newInstance(String entrypt, Class[] argt, Object[] argv)
    {
        try {
            return callStaticClassMethod(entrypt, argt, argv);
        } catch (Exception ex) {
            final String opname = "newInstance";
            TheLogger.debug(_class_name, opname, "IGNORE", ex);
            return null;
        }
    }
}
