// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>The <tt>TheLogger</tt> class provides very basic log features. Messages are log to the
 **  standard error output. By default, no message is displayed. To turn on the <tt>LOG</tt>
 **  or <tt>DEBUG</tt> levels, the <tt>log</tt> or <tt>debug</tt> Java system property must be
 **  set with a value of "true". Note that turning on the <tt>DEBUG</tt> level also turns on
 **  the <tt>LOG</tt> level. Finally, the <tt>runtime.id</tt> property may also be set to display
 **  a process specific information.</p>
 **
 **  The format of the displayed message is the following:<br>
 **  LEVEL:runtime.id:[classname/methodname] message<br>
 **
 **/
public class TheLogger
{
    static public int FATAL = 0;
    static public int ERROR = 1;
    static public int LOG = 2;
    static public int DEBUG = 3;

    static private boolean _debug_on;
    static private boolean _log_on;
    static private String _runtime_name;

    // NOTE: 
    //static private java.io.FileWriter _log_file;

    static {
        // default init
        _log_on = false;
        _debug_on = false;

        // check if log is on
        String flag = System.getProperty("log");
        if ((flag!=null) && (flag.equals("true"))) {
            _log_on = true;
        }

        // check if debug is on (in that case, log is also activated)
        flag = System.getProperty("debug");
        if ((flag!=null) && (flag.equals("true"))) {
            _debug_on = true;
            _log_on = true;
        }

        // obtain runtime name from properties
        //_runtime_name = System.getProperty("runtime.id");

        // create log file
        /*
        try {
            String fname = "logger.out";
            _log_file = new java.io.FileWriter(fname);
        } catch (Exception ex) {
            // ignore
        }
        */
    }

    static public String
    getIndentation(int length)
    {
        char[] cindent = new char[length];
        for (int i=0;i<cindent.length;i++) {
            cindent[i] = ' ';
        }

        return new String(cindent);
    }

    static public boolean
    debugOn()
    {
        return _debug_on;
    }

    static public boolean
    logOn()
    {
        return _log_on;
    }


    static public String
    getRuntimeName()
    {
        return System.getProperty("runtime.id");
    }

    static public void
    log(int level, String clazz, String meth, String msg)
    {
        if (level==ERROR)
            error(clazz, meth, msg);
        else if (level==LOG)
            log(clazz, meth, msg);
        else if (level==DEBUG)
            debug(clazz, meth, msg);
    }

    static public void
    log(int level, String clazz, String meth, String msg, Exception ex)
    {
        if (level==ERROR)
            error(clazz, meth, msg, ex);
        else if (level==LOG)
            log(clazz, meth, msg, ex);
        else if (level==DEBUG)
            debug(clazz, meth, msg);
    }

    static public void
    debug(String clazz, String meth, String msg)
    {
        if (!debugOn()) 
            return ;

        String rmsg = "DEBUG:"+getRuntimeName()+":["+clazz+"/"+meth+"] "+msg;
        System.err.println(rmsg);

        //Thread.currentThread().dumpStack();

        /*
        if (_log_file!=null) {
            try { _log_file.write(rmsg+"\n"); } catch (Exception exc) { }
        }
        */
    }

    static public void
    debug(String clazz, String meth, String msg, Throwable ex)
    {
        if (!debugOn()) 
            return ;

        String rmsg = "DEBUG:"+getRuntimeName()+":["+clazz+"/"+meth+"] ";
        String indent = getIndentation(rmsg.length());

        System.err.println(rmsg+msg);
        System.err.println(indent+ex.getMessage());

        ex.printStackTrace();
        /*
        if (_log_file!=null) {
            try {
                _log_file.write(rmsg+msg+"\n");
                _log_file.write(indent+ex.getMessage()+"\n");
            } catch (Exception exc) {
            }
        }
        */
    }

    static public void
    log(String clazz, String meth, String msg)
    {
        if (!logOn()) 
            return ;

        String rmsg = "LOG:"+getRuntimeName()+":["+clazz+"/"+meth+"] "+msg;
        System.err.println(rmsg);

        //Thread.currentThread().dumpStack();

        /*
        if (_log_file!=null) {
            try { _log_file.write(rmsg+"\n"); } catch (Exception exc) { }
        }
        */
    }

    static public void
    log(String clazz, String meth, String msg, Throwable ex)
    {
        if (!logOn()) 
            return ;

        String rmsg = "LOG:"+getRuntimeName()+":["+clazz+"/"+meth+"] ";
        String indent = getIndentation(rmsg.length());

        System.err.println(rmsg+msg);
        System.err.println(indent+ex.getMessage());

        ex.printStackTrace();
        /*
        if (_log_file!=null) {
            try {
                _log_file.write(rmsg+msg+"\n");
                _log_file.write(indent+ex.getMessage()+"\n");
            } catch (Exception exc) {
            }
        }
        */
    }

    static public void
    error(String clazz, String meth, String msg)
    {
        String rmsg = "ERROR:"+getRuntimeName()+":["+clazz+"/"+meth+"] "+msg;
        System.err.println(rmsg);

        //        try { _log_file.write(rmsg+"\n"); } catch (Exception exc) { }

        //Thread.currentThread().dumpStack();
        throw new Error();
    }

    static public void
    error(String clazz, String meth, String msg, Throwable ex)
    {
        String rmsg = "ERROR:"+getRuntimeName()+":["+clazz+"/"+meth+"] ";
        String indent = getIndentation(rmsg.length());

        System.err.println(rmsg+msg);
        System.err.println(indent+ex.getMessage());

        /*
        if (_log_file!=null) {
            try {
                _log_file.write(rmsg+msg+"\n");
                _log_file.write(indent+ex.getMessage()+"\n");
            } catch (Exception exc) {
            }
        }
        */

        ex.printStackTrace();
        throw new Error();
    }
}
