@echo off
REM ==================================================================== 
REM
REM   ECM: The Extensible Container Model
REM   Copyright (C) 2004 THALES
REM   Contact: openccm-ecm@objectweb.org
REM
REM   This library is free software; you can redistribute it and/or
REM   modify it under the terms of the GNU Lesser General Public
REM   License as published by the Free Software Foundation; either
REM   version 2.1 of the License, or any later version.
REM
REM   This library is distributed in the hope that it will be useful,
REM   but WITHOUT ANY WARRANTY; without even the implied warranty of
REM   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
REM   Lesser General Public License for more details.
REM
REM   You should have received a copy of the GNU Lesser General Public
REM   License along with this library; if not, write to the Free Software
REM   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
REM   USA
REM
REM   Initial developer(s): Mathieu Vadet
REM   Initial funding: IST COACH European Project (IST-2001-34445)
REM                    http://www.ist-coach.org
REM
REM ==================================================================== 


REM
REM  Starts a CORBA CosNaming service
REM

setlocal

goto begin

:usage
    echo usage: ns_start [options]
    echo Starts a CORBA CosNaming service.
    echo --
    echo The following options are supported:
    echo   /h, /help    Print this message
    echo   /debug       Activate debug mode (optional)
    echo   name         The logical name of the CORBA CosNaming service, NS_at_hostname by default (optional)
    exit /B 1

:begin
set name=
set debug=

:parse_args
if not "%1"=="" (
    if "%1"=="/h" (
        goto usage
    ) else if "%1"=="/help" (
        goto usage
    ) else if "%1"=="/debug" (
        set debug=t
    ) else (
        set name=%1
    )

    shift
    goto parse_args
)

REM check if name is set
if not defined name (
    if defined debug (
        echo WARNING: Will use default name for CORBA CosNaming service.
    )

    hostname > %TEMP%\hostname.tmp
    for /f %%i in (%TEMP%\hostname.tmp) do (
        set name=NS_at_%%i
    )
    del %TEMP%\hostname.tmp 2> nul
)

REM check if the service is started
if exist %CORBA_RUNTIME_REPOSITORY%\%name%.pid (
    if defined debug (
        echo WARNING: The CORBA CosNaming service with logical name: %name% is already started.
    )
)

if defined debug (
    echo INFO: Starting OpenORB 1.4.0 CORBA CosNaming service ...
)

call @OpenCCM.install.bin.dir@\launcher fork "" "@ECM.install.launcher.dir@/ns.xml" %CORBA_RUNTIME_REPOSITORY%\%name%.ior %CORBA_RUNTIME_REPOSITORY%\%name%.pid

REM copy the NamingContextExt.ior file to %CORBA_RUNTIME_REPOSITORY%\%name%.ior
REM as we use the --writeIORFile option
:waitloop
if not exist NamingContextExt.ior (
    goto waitloop
)

move NamingContextExt.ior %CORBA_RUNTIME_REPOSITORY%\%name%.ior

if defined debug (
    echo INFO: OpenORB 1.4.0 CORBA CosNaming service started.
)
