#! /bin/sh
# ==================================================================== 
#
#   ECM: The Extensible Container Model
#   Copyright (C) 2004 THALES
#   Contact: openccm-ecm@objectweb.org
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU Lesser General Public
#   License as published by the Free Software Foundation; either
#   version 2.1 of the License, or any later version.
#
#   This library is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#   Lesser General Public License for more details.
#
#   You should have received a copy of the GNU Lesser General Public
#   License along with this library; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#   USA
#
#   Initial developer(s): Mathieu Vadet
#   Initial funding: IST COACH European Project (IST-2001-34445)
#                    http://www.ist-coach.org
#
# ==================================================================== 


#
#  Build script
#

# source variables
. make.config

# JDK (no choice)
JDK_HOME=$sun_jdk_1_4_0_dir
JDK_NAME=$sun_jdk_1_4_0_name
JDK_BIN=${JDK_HOME}/bin

# Ant (no choice)
ANT_HOME=$ant_1_6_0

# OpenCCM (no choice)
OPENCCM_HOME=$openccm_0_8_0

# usage
usage() {
    echo "make.sh [options]"
    echo "Builds or installs the ECM."
    echo "--"
    echo "The following options are supported: "
    echo "  -h, --help    Print this message"
    echo "  --build       Build the ECM with a specific ORB"
    echo "  --demos       Build the ECM demonstrations with a specific ORB"
    echo "  --install     Install a built ECM in the filesystem"
    exit 1;
}

# obtain build configuration
select_orb() {
    echo "Select ORB: 1) OpenORB 1.3.1   2) OpenORB 1.4.0    3) ORBacus 4.1.0"
    read res ;
    if [ "$res" = "1" ] ;
    then
        ORB_HOME=$openorb_1_3_1_dir
        ORB_NAME=$openorb_1_3_1_name
        echo "Will use $ORB_NAME" ;
    elif [ "$res" = "2" ] ;
    then
        ORB_HOME=$openorb_1_4_0_dir
        ORB_NAME=$openorb_1_4_0_name
        echo "Will use $ORB_NAME" ;
    elif [ "$res" = "3" ] ;
    then 
        ORB_HOME=$orbacus_4_1_0_dir 
        ORB_NAME=$orbacus_4_1_0_name
        echo "Will use $ORB_NAME" ;
    else
        select_orb ;
    fi
}


# obtain build configuration
install_orb() {
    if [ -z "$default_install_dir" ] ;
    then
        echo "Installation directory: "
        read INSTALL_DIR ;
    else
        select_orb
        INSTALL_DIR=$default_install_dir/$ORB_NAME ;
    fi

    MAKE_FILE=main/ant/install.xml
    props="$props -DECM.install.dir=$INSTALL_DIR"
    echo "Will install ECM in: $INSTALL_DIR"
}


# parse arguments
params=
props=
MAKE_FILE=main/ant/ecm.xml
opt=

for param in $@ ;
do
    if [ "$param" = "-h" ] || [ "$param" = "--help" ] ;
    then
        usage;
    elif [ "$param" = "--build" ] ;
    then
        opt=t
        select_orb ;
    elif [ "$param" = "--demos" ] ;
    then
        opt=t
        MAKE_FILE="main/ant/ecm.xml demos "
        select_orb ;
    elif [ "$param" = "--install" ] ;
    then 
        opt=t
        install_orb ;
    elif [ "$param" = "--clean" ] ;
    then 
        opt=t
        MAKE_FILE="main/ant/ecm.xml clean" ;
    elif [ "$param" = "--tasks" ] ;
    then 
        opt=t
        MAKE_FILE=main/ant/tasks.xml ;
    elif [ "$param" = "--release" ] ;
    then
        opt=t
        MAKE_FILE="main/ant/ecm.xml release" ;
    elif [ "$param" = "--doc" ] ;
    then 
        opt=t
        MAKE_FILE="main/ant/ecm.xml doc" ;
    else
        # NOTE: re-build the parameter list without our --xx options
        # as ant will not understand it ...
        params="$params $param" ;
    fi
done

# check that an option was set
if [ -z "$opt" ] ;
then 
    echo "ERROR: --build, --demos or --install option expected."
    exit 1;
fi


## set path
# Determinate what the path separator is:
# - On Unix systems, it is ':'
# - On CygWin systems, it is ';'
#
PS=':'
if [ $OSTYPE = "cygwin32" ] || [ $OSTYPE = "cygwin" ] ; then
    PS=';'
fi

# add JDK bin
PATH=${JDK_BIN}${PS}${PATH}
export PATH


## set classpath for ant
# Concatenate all the libraries in the ${ANT_HOME} directory and
# append them to the classpath environment variable.
#
CLASSPATH=`echo ${ANT_HOME}/lib/*.jar | tr ' ' ${PS}`${PS}$CLASSPATH
CLASSPATH=$JDK_HOME/lib/tools.jar${PS}$CLASSPATH

# add ECM tasks to path
CLASSPATH=${CLASSPATH}${PS}`pwd`/externals/Ant-1.6.0/lib/ecm_ant_tasks.jar
# add ant-contrib to path
CLASSPATH=${CLASSPATH}${PS}`pwd`/externals/Ant-1.6.0/lib/ant-contrib-0.6.jar

# source OpenCCM if not already done
if [ -z "$OpenCCM_HOMEDIR" ] ;
then
    . $OPENCCM_HOME/bin/envi.OpenCCM.sh
fi


# delegate to Ant
$JDK_BIN/java -cp $CLASSPATH -Dant.home=${ANT_HOME} -Dant.dir=${ANT_HOME} -Djava.name=${JDK_NAME} -Djava.dir=${JDK_HOME} -DECM.dir=`pwd` -DOpenCCM.install.dir=${OPENCCM_HOME} -DORB.name=${ORB_NAME} -DORB.dir=${ORB_HOME} $props org.apache.tools.ant.Main $params -q -buildfile $MAKE_FILE
