// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>.</p>
 **/
public class ContainerImpl
extends org.omg.CORBA.LocalObject
implements Servant, org.omg.Components.Deployment.ContainerOperations
{
    // component server
    static private String _class_name = "ContainerImpl";
    static final private String _type_id =  org.omg.Components.Deployment.ContainerHelper.id();
    private ORBService _orb_service;
    private String _ns_sref;
    private String _extci_sref;
    private java.util.ArrayList _home_refs;  // (list of ::Components::CCMHome)
    private org.omg.Components.ConfigValue[] _configuration;
    private org.omg.Components.Deployment.ComponentServer _cs_ref;

    // default constructor
    public
    ContainerImpl()
    {
        // component server
        _orb_service = null;
        _ns_sref = null;
        _extci_sref = null;
        _home_refs = new java.util.ArrayList();
        _configuration = new org.omg.Components.ConfigValue[0];
        _cs_ref = null;
    }

    //
    //  Entry point
    //

    static public Servant
    create_servant()
    {
        return new ContainerImpl();
    }

    //
    //  internal operations
    //

    //
    //  IDL:org/objectweb/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        // obtain services
        ServantConfiguration scfg = (ServantConfiguration)cfg;
        _orb_service = scfg.orb_service();

        // extract references which must be passed to the services set
        org.omg.CORBA.Object obj = null;
        // extract NS ref
        obj = _orb_service.resolve_initial_references("NameService");

        // check if found
        if (obj==null) {
            // NOTE: should not happen
            final String opname = "system_configuration_complete";
            final String msg = "FAILED (NS not found)";
            TheLogger.error(_class_name, opname, msg);
            return ;
        }

        _ns_sref = _orb_service.object_to_string(obj);

        // extract ExtCI ref
        obj = _orb_service.resolve_initial_references("ExtComponentInstallation");

        // check if found
        if (obj==null) {
            // NOTE: should not happen
            final String opname = "system_configuration_complete";
            final String msg = "FAILED (ExtCI not found)";
            TheLogger.error(_class_name, opname, msg);
            return ;
        }

        _extci_sref = _orb_service.object_to_string(obj);

        // NOTE: how is the ComponentActivator reference obtained ?
        //  - using the (local) name service
        //  - using a config value
        //  - using the system configuration 
        //  - other ?

    }

    final public void
    destroy()
    {
        // destroy all installed home
        org.omg.Components.CCMHome[] refs = get_homes();
        for (int i=0;i<refs.length;i++) {
            try {
                //
                refs[i].remove_home();

                // NOTE: TODO: deactivate home servants
            } catch (org.omg.Components.RemoveFailure ex) {
                // ignore
                final String opname = "destroy";
                TheLogger.debug(_class_name, opname, "IGNORE", ex);
                return ;
            }
        }

        // clear list
        _home_refs.clear();
    }

    //
    //  IDL:org/objectweb/corba/runtime/Servant:1.0
    //

    final public String
    type_id()
    {
        return _type_id;
    }

    final public org.omg.PortableServer.Servant
    as_native_servant()
    {
        return new org.omg.Components.Deployment.ContainerPOATie(this);
    }

    //
    //  IDL:omg.org/Components/Deployment/Container:1.0
    //

    final public org.omg.Components.ConfigValue[]
    configuration()
    {
        return _configuration;
    }

    final public org.omg.Components.Deployment.ComponentServer
    get_component_server()
    {
        return _cs_ref;
    }

    final public org.omg.Components.CCMHome
    install_home(String uuid, String entrypt, org.omg.Components.ConfigValue[] config)
    throws org.omg.Components.Deployment.UnknownImplId,
           org.omg.Components.Deployment.ImplEntryPointNotFound,
           org.omg.Components.Deployment.InstallationFailure,
           org.omg.Components.Deployment.InvalidConfiguration
    {
        // extract configvalues infos: none at present
       
        // build configuration
        ComponentRuntimeConfiguration cfg = new ComponentRuntimeConfiguration();

        // NOTE: need to propagate the ExtCI and NS refs
        org.coach.ECM.DegeneratedServiceRef[] dsrefs = new org.coach.ECM.DegeneratedServiceRef[2];
        dsrefs[0] = new org.coach.ECM.DegeneratedServiceRef();
        dsrefs[0].orb_registration_name = "NameService";
        dsrefs[0].initial_reference = _ns_sref;
        dsrefs[1] = new org.coach.ECM.DegeneratedServiceRef();
        dsrefs[1].orb_registration_name = "ExtComponentInstallation";
        dsrefs[1].initial_reference = _extci_sref;
        cfg.dservice_refs = dsrefs;

        cfg.orb_service = _orb_service;
        cfg.implementation_uuid = uuid;

        // delegate to component runtime
        org.omg.Components.CCMHome href = ComponentRuntime.loadHome(cfg);

        // store
        _home_refs.add(href);

        return href;
    }

    final public void
    remove_home(org.omg.Components.CCMHome href)
    throws org.omg.Components.RemoveFailure
    {
        // remove from storage
        org.omg.Components.CCMHome[] refs = get_homes();
        int i=0;
        for (;i<refs.length;i++) {
            if (href._is_equivalent(refs[i])) {
                _home_refs.remove(i);

                // NOTE: only call remove on the container if it was found
                href.remove_home();

                // NOTE: TODO: deactivate home servant
                break;
            }
        }

        // if it wasn't found, report removal failure
        if (i==refs.length) {
            throw new org.omg.Components.RemoveFailure();
        }
    }

    final public org.omg.Components.CCMHome[]
    get_homes()
    {
        return (org.omg.Components.CCMHome[])_home_refs.toArray(new org.omg.Components.CCMHome[0]);
    }

    final public void
    remove()
    throws org.omg.Components.RemoveFailure
    {
        // destroy
        destroy();
    }
}
