// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Base implementation of service and component archive servants.</p>
 **/
abstract public class ArchiveServantBase
extends org.omg.CORBA.LocalObject
{
    // archive
    static private String _class_name = "ArchiveServantBase";
    private String _uuid;
    private String _archive_location;
    private String _archive_cache;
    private java.util.Hashtable _entry2loc;

    protected
    ArchiveServantBase(String uuid,
                       String loc)
    {
        // archive
        _uuid = uuid;
        _archive_location = loc;
        _archive_cache = null;
        _entry2loc = new java.util.Hashtable();
    }

    //
    //  abstract operations
    //

    abstract protected ORBService
    getORBService();

    //
    //  internal operations (for inherited classes)
    //

    final protected java.util.zip.ZipFile
    openZip()
    {
        if (_archive_cache==null) {
            // compute archive cache directory (for file extraction)
            int idx = _archive_location.lastIndexOf(".");
            _archive_cache = _archive_location.substring(0, idx);

            // create archive cache
            new java.io.File(_archive_cache).mkdirs();
        }

        try {
            return new java.util.zip.ZipFile(_archive_location);
        } catch(java.lang.Exception ex) {
            // NOTE: TODO: should be reported as an exception
            final String opname = "openZip";
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        }
    }

    final protected String
    extractFile(java.util.zip.ZipFile zip,
                java.util.zip.ZipEntry entry)
    {
        final String opname = "extractFile";
        java.io.InputStream in = null;
        java.io.FileOutputStream out = null;

        try {
            in = zip.getInputStream(entry);
            java.io.File fout = new java.io.File(_archive_cache+"/"+entry.getName());
            fout.getParentFile().mkdirs();
            out = new java.io.FileOutputStream(fout);
        } catch (java.io.IOException ex) {
            // NOTE: TODO: should be reported as an exception
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        }

        int nread = 0;
        byte[] buffer = new byte[2048];
        try {
            while (nread!=-1) {
                nread = in.read(buffer, 0, 2048);
                if (nread!=-1) out.write(buffer, 0, nread);
            }

            in.close();
            out.close();
        } catch (java.io.IOException ex) {
            // NOTE: TODO: should be reported as an exception
            final String msg = "FAILED (entry: "+entry.getName()+")";
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        }

        return _archive_cache+"/"+entry.getName();
    }

    //
    //  IDL:coach.org/ECM/Archive:1.0
    //

    final public String
    get_fileinarchive_location(String name)
    {
        final String opname = "get_fileinarchive_location";

        // check if already unzipped
        String location = (String)_entry2loc.get(name);
        if (location!=null) {
            return location;
        }

        // open zip
        java.util.zip.ZipFile zip = openZip();

        // extract CSD location
        java.util.Enumeration entries = zip.entries();
        java.util.zip.ZipEntry entry = null;
        java.util.zip.ZipEntry fentry = null;
        while (entries.hasMoreElements()) {
            entry = (java.util.zip.ZipEntry)entries.nextElement();
            if (entry.getName().equals(name)) {
                fentry = entry;
                break;
            }
        }

        // check if found
        if (fentry==null) {
            final String msg = "FAILED (entry not found: "+name+")";
            TheLogger.error(_class_name, opname, msg);
        }

        // extract file
        location = extractFile(zip, fentry);

        // store
        _entry2loc.put(name, location);

        return location;
    }

    final public String
    get_href_location(String href)
    {
        final String opname = "get_href_location";
        final String msg = "FAILED (not implemented, rethrown)";
        TheLogger.debug(_class_name, opname, msg);

        throw new org.omg.CORBA.NO_IMPLEMENT();
    }

    final public String
    get_link_location(String link)
    {
        final String opname = "get_link_location";
        final String msg = "FAILED (not implemented, rethrown)";
        TheLogger.debug(_class_name, opname, msg);

        throw new org.omg.CORBA.NO_IMPLEMENT();
    }

    final public String
    get_ins_as_objref(String ins)
    {
        RegistrationService regs = org.objectweb.corba.runtime.Runtime.getRegistrationService();
        INSRegistrationScheme scheme = (INSRegistrationScheme)regs.get_scheme(INSRegistrationScheme.SCHEME_ID);

        org.omg.CORBA.Object ref = scheme.lookup(ins, getORBService());
        return getORBService().object_to_string(ref);
    }

    final public String
    uuid()
    {
        return _uuid;
    }
}
