// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

// import of some PortableServer decls to avoid to long lines
import org.omg.PortableServer.THREAD_POLICY_ID;
import org.omg.PortableServer.ThreadPolicy;
import org.omg.PortableServer.ThreadPolicyValue;
import org.omg.PortableServer.ThreadPolicyValueHelper;
import org.omg.PortableServer.LIFESPAN_POLICY_ID;
import org.omg.PortableServer.LifespanPolicy;
import org.omg.PortableServer.LifespanPolicyValue;
import org.omg.PortableServer.LifespanPolicyValueHelper;
import org.omg.PortableServer.ID_UNIQUENESS_POLICY_ID;
import org.omg.PortableServer.IdUniquenessPolicy;
import org.omg.PortableServer.IdUniquenessPolicyValue;
import org.omg.PortableServer.IdUniquenessPolicyValueHelper;
import org.omg.PortableServer.ID_ASSIGNMENT_POLICY_ID;
import org.omg.PortableServer.IdAssignmentPolicy;
import org.omg.PortableServer.IdAssignmentPolicyValue;
import org.omg.PortableServer.IdAssignmentPolicyValueHelper;
import org.omg.PortableServer.IMPLICIT_ACTIVATION_POLICY_ID;
import org.omg.PortableServer.ImplicitActivationPolicy;
import org.omg.PortableServer.ImplicitActivationPolicyValue;
import org.omg.PortableServer.ImplicitActivationPolicyValueHelper;
import org.omg.PortableServer.SERVANT_RETENTION_POLICY_ID;
import org.omg.PortableServer.ServantRetentionPolicy;
import org.omg.PortableServer.ServantRetentionPolicyValue;
import org.omg.PortableServer.ServantRetentionPolicyValueHelper;
import org.omg.PortableServer.REQUEST_PROCESSING_POLICY_ID;
import org.omg.PortableServer.RequestProcessingPolicy;
import org.omg.PortableServer.RequestProcessingPolicyValue;
import org.omg.PortableServer.RequestProcessingPolicyValueHelper;

/**
 **  <p>Default factory implementation for the <tt>ComponentPOAService</tt> system service.</p>
 **/
public class ComponentPOAFactoryImpl
extends org.omg.CORBA.LocalObject
implements SystemFactory
{
    // system component
    static final private String _class_name = "ComponentPOAFactoryImpl";

    // default constructor
    protected
    ComponentPOAFactoryImpl()
    {
    }

    //
    //  entry point
    //

    static public SystemFactory
    create_factory()
    {
        return new ComponentPOAFactoryImpl();
    }

    //
    // internal operations
    //

    static private org.omg.CORBA.Policy[]
    checkPolicies(org.omg.CORBA.Policy[] pols,
                  ORBService orbs)
    {
        String opname = "checkPolicies";

        // check that the policy set is ok
        // and add missing policies
        // the following policy set must be specified:
        //   - Theading: ORB, SINGLE OR MAIN (if not, then use ORB)
        //   - Lifespan: TRANSIENT or PERSISTENT (if not, then use TRANSIENT)
        //   - IdUniqueness: MULTIPLE_ID or UNIQUE_ID (if not, then use UNIQUE_ID)
        //   - IdAssignment: USER_ID
        //   - ServantRetention: RETAIN
        //   - RequestProcessing: USE_SERVANT_MANAGER
        //   - ImplicitActivation: NO_IMPLICIT_ACTIVATION
        java.util.Vector rpols = new java.util.Vector();

        boolean threadingpol_set = false;
        boolean lifespanpol_set = false;
        boolean iduniqpol_set = false;
        boolean idassignpol_set = false;
        boolean servantretpol_set = false;
        boolean reqprocpol_set = false;
        boolean implactpol_set = false;
        for (int i=0;i<pols.length;i++) {
            if (pols[i].policy_type()==THREAD_POLICY_ID.value) {
                // no check
                rpols.add(pols[i]);
                threadingpol_set = true;
            }
            else if (pols[i].policy_type()==LIFESPAN_POLICY_ID.value) {
                // no check
                rpols.add(pols[i]);
                lifespanpol_set = true;
            }
            else if (pols[i].policy_type()==ID_UNIQUENESS_POLICY_ID.value) {
                // no check
                rpols.add(pols[i]);
                iduniqpol_set = true;
            }
            else if (pols[i].policy_type()==ID_ASSIGNMENT_POLICY_ID.value) {
                // check USER_ID
                IdAssignmentPolicy idassignpol = (IdAssignmentPolicy)pols[i];
                if (idassignpol.value()!=IdAssignmentPolicyValue.USER_ID) {
                    // NOTE: ignore the policy setting
                    String msg = "IGNORE (was expecting USER_ID)";
                    TheLogger.debug(_class_name, opname, msg);
                } else {
                    rpols.add(pols[i]);
                    idassignpol_set = true;
                }
            }
            else if (pols[i].policy_type()==IMPLICIT_ACTIVATION_POLICY_ID.value) {
                // check NO_IMPLICIT_ACTIVATION
                ImplicitActivationPolicy implactpol = (ImplicitActivationPolicy)pols[i];
                if (implactpol.value()!=ImplicitActivationPolicyValue.NO_IMPLICIT_ACTIVATION) {
                    // NOTE: ignore the policy setting
                    String msg = "IGNORE (was expecting NO_IMPLICIT_ACTIVATION)";
                    TheLogger.debug(_class_name, opname, msg);
                } else {
                    rpols.add(pols[i]);
                    implactpol_set = true;
                }
            }
            else if (pols[i].policy_type()==SERVANT_RETENTION_POLICY_ID.value) {
                // check RETAIN
                ServantRetentionPolicy servantretpol = (ServantRetentionPolicy)pols[i];
                if (servantretpol.value()!=ServantRetentionPolicyValue.RETAIN) {
                    // NOTE: ignore the policy setting
                    String msg = "IGNORE (was expecting RETAIN)";
                    TheLogger.debug(_class_name, opname, msg);
                } else {
                    rpols.add(pols[i]);
                    servantretpol_set = true;
                }
            }
            else if (pols[i].policy_type()==REQUEST_PROCESSING_POLICY_ID.value) {
                // check USE_ACTIVE_OBJECT_MAP_ONLY
                RequestProcessingPolicy reqprocpol = (RequestProcessingPolicy)pols[i];
                if (reqprocpol.value()!=RequestProcessingPolicyValue.USE_ACTIVE_OBJECT_MAP_ONLY) {
                    // NOTE: ignore the policy setting
                    String msg = "IGNORE (was expecting USE_ACTIVE_OBJECT_MAP_ONLY)";
                    TheLogger.debug(_class_name, opname, msg);
                } else {
                    rpols.add(pols[i]);
                    reqprocpol_set = true;
                }
            }
            else {
                rpols.add(pols[i]);
            }
        }

        // complete missing policies
        org.omg.CORBA.Policy pol = null;
        org.omg.CORBA.Any value = null;
        if (!threadingpol_set) {
            value = orbs.create_any();
            ThreadPolicyValueHelper.insert(value, ThreadPolicyValue.ORB_CTRL_MODEL);
            pol = orbs.create_policy(THREAD_POLICY_ID.value, value);
            rpols.add(pol);
        }

        if (!lifespanpol_set) {
            value = orbs.create_any();
            LifespanPolicyValueHelper.insert(value, LifespanPolicyValue.TRANSIENT);
            pol = orbs.create_policy(LIFESPAN_POLICY_ID.value, value);
            rpols.add(pol);
        }

        if (!iduniqpol_set) {
            value = orbs.create_any();
            IdUniquenessPolicyValueHelper.insert(value, IdUniquenessPolicyValue.UNIQUE_ID);
            pol = orbs.create_policy(ID_UNIQUENESS_POLICY_ID.value, value);
            rpols.add(pol);
        }

        if (!idassignpol_set) {
            value = orbs.create_any();
            IdAssignmentPolicyValueHelper.insert(value, IdAssignmentPolicyValue.USER_ID);
            pol = orbs.create_policy(ID_ASSIGNMENT_POLICY_ID.value, value);
            rpols.add(pol);
        }

        if (!servantretpol_set) {
            value = orbs.create_any();
            ServantRetentionPolicyValueHelper.insert(value, ServantRetentionPolicyValue.RETAIN);
            pol = orbs.create_policy(SERVANT_RETENTION_POLICY_ID.value, value);
            rpols.add(pol);
        }

        if (!reqprocpol_set) {
            value = orbs.create_any();
            RequestProcessingPolicyValueHelper.insert(value, RequestProcessingPolicyValue.USE_SERVANT_MANAGER);
            pol = orbs.create_policy(REQUEST_PROCESSING_POLICY_ID.value, value);
            rpols.add(pol);
        }

        if (!implactpol_set) {
            value = orbs.create_any();
            ImplicitActivationPolicyValueHelper.insert(value, ImplicitActivationPolicyValue.NO_IMPLICIT_ACTIVATION);
            pol = orbs.create_policy(IMPLICIT_ACTIVATION_POLICY_ID.value, value);
            rpols.add(pol);
        }

        return (org.omg.CORBA.Policy[])rpols.toArray(new org.omg.CORBA.Policy[0]);
    }

    static private org.omg.PortableServer.POA
    createPOA(POAConfiguration cfg)
    {
        //
        ORBService orbs = cfg.orb_service();

        // obtain root POA
        org.omg.PortableServer.POA root_poa = null;
        root_poa = org.omg.PortableServer.POAHelper.narrow(orbs.resolve_initial_references("RootPOA"));

        // create new POA, with servant locator
        org.omg.PortableServer.POA poa = null;
        org.omg.CORBA.Policy[] rpols = checkPolicies(cfg.policies(), orbs);
        String name = "";
        try {
            // check name
            if ((cfg.name()==null) || (cfg.name().equals(""))) {
                name = Double.toString(Math.random());
            }
            else {
                name = cfg.name();
            }

            poa = root_poa.create_POA(name, null, rpols);
            poa.the_POAManager().activate();

            // create servant manager
            ComponentServantActivatorImpl csa = new ComponentServantActivatorImpl();
            poa.set_servant_manager(csa);
        } catch (Exception ex) {
            String opname = "createPOA";
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        }

        return poa;
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemFactory:1.0
    //

    final public SystemComponent
    create_system_component(SystemConfiguration cfg)
    {
        ComponentPOAConfiguration poacfg = (ComponentPOAConfiguration)cfg;
        ORBService orbs = poacfg.orb_service();

        // create a new POA service instance
        ComponentPOAServiceImpl poas = new ComponentPOAServiceImpl();

        // home POA (do not use config)
        POAConfiguration hpoacfg = new POAConfigurationImpl(null, null, orbs);

        org.omg.PortableServer.POA hpoa = createPOA(hpoacfg);
        poas.setHomePOA(hpoa);

        // component POA
        org.omg.PortableServer.POA cpoa = createPOA(poacfg);
        poas.setComponentPOA(cpoa);

        // complete configuration
        poas.system_configuration_complete(poacfg);

        return poas;
    }
}
