// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Default implementation of the <tt>PortableServer::ServantActivator</tt> OMG IDL interface.</p>
 **
 **  @see org.objectweb.ccm.runtime.ComponentPOAServiceImpl ComponentPOAServiceImpl
 **/
class ComponentServantActivatorImpl
extends org.omg.CORBA.LocalObject
implements org.omg.PortableServer.ServantActivator
{
    // 
    static final private String _class_name = "ComponentServantActivatorImpl";
    private ORBService _orb_service;
    private ServicesSet _services_set;
    private java.util.HashMap _id2home;          // (home object id, home exe)
    private java.util.HashMap _component_ids;    // (object id, null)
    private java.util.HashMap _id2pcomp;         // (object id, passivate component)
    private java.util.HashMap _id2acomp;         // (object id, activated component)

    private MonolithicIdCodec _midcodec;
    private SegmentedIdCodec _sidcodec;

    public
    ComponentServantActivatorImpl()
    {
        //
        _orb_service = null;
        _services_set = null;
        _id2home = new java.util.HashMap();
        _component_ids = new java.util.HashMap();
        _id2pcomp = new java.util.HashMap();
        _id2acomp = new java.util.HashMap();

        _midcodec = null;
        _sidcodec = null;
    }

    //
    //  internal operations
    //

    private org.omg.Components.ExecutorSegmentBase
    lookupPassivated(byte[] id)
    {
        final String opname = "lookupPassivated";

        // check if the request targets a passivated executor
        String pcomp = (String)_id2pcomp.remove(new String(id));
        if (pcomp!=null) {
            // unmarshall executor
            try {
                java.io.ByteArrayInputStream bin=  new java.io.ByteArrayInputStream(pcomp.getBytes());
                java.io.ObjectInputStream oin = new java.io.ObjectInputStream(bin);
                Object obj = oin.readObject();

                if (obj instanceof org.omg.Components.ExecutorSegmentBase) {
                    return (org.omg.Components.ExecutorSegmentBase)obj;
                } else {
                    // NOTE: should not happen
                    TheLogger.error(_class_name, opname, "FAILED (not a executor segment: "+obj.getClass()+"");
                    return null;
                }
            } catch (Exception ex) {
                // NOTE: what can be done if serialization fails ?
                TheLogger.error(_class_name, opname, "FAILED", ex);
                return null;
            }
        }

        return null;
    }

    //
    //  friend operations
    //

    final protected void
    setConfiguration(ORBService orbs, ServicesSet sset)
    {
        _orb_service = orbs;
        _services_set = sset;

        // create codecs
        _midcodec = new MonolithicIdCodec(_orb_service);
        _sidcodec = new SegmentedIdCodec(_orb_service);
    }

    synchronized final protected void
    registerHome(byte[] id, String uuid,
                 org.omg.Components.HomeExecutor hexe,
                 CallInterceptorFactory ifact,
                 org.omg.Components.CCM2Context ctx)
    {
        CSAStorage storage = null;
        if (ifact!=null) {
            storage = new CSAStorage(hexe, ctx, ifact);
        } else {
            storage = new CSAStorage(hexe, ctx);
        }

        // store
        _id2home.put(new String(id), storage);
    }

    synchronized final protected void
    registerComponent(byte[] id)
    {
        // store
        _component_ids.put(new String(id), null);
    }

    synchronized final protected void
    unregisterComponent(byte[] id)
    {
        // remove from storage
        _component_ids.remove(new String(id));
    }

    //
    //  IDL:omg.org/PortableServer/ServantManager:1.0
    //

    //
    //  IDL:omg.org/PortableServer/ServantActivator:1.0
    //

    // NOTE: no sychronisation required as the POA shall serialize
    // incarnation requests and incarnate/etherealize are mutually exclusive
    final public org.omg.PortableServer.Servant
    incarnate(byte[] id, org.omg.PortableServer.POA poa)
    throws org.omg.PortableServer.ForwardRequest
    {
        final String opname = "incarnate";
        try {
            return unsafe_incarnate(id, poa);
        } catch (org.omg.PortableServer.ForwardRequest ex) {
            // rethrow 
            throw ex;
        } catch (Throwable ex) {
            TheLogger.debug(_class_name, opname, "FAILED", ex);
            return null;
        } 
    }

    final public org.omg.PortableServer.Servant
    unsafe_incarnate(byte[] id, org.omg.PortableServer.POA poa)
    throws org.omg.PortableServer.ForwardRequest
    {
        final String opname = "unsafe_incarnate";

        //  check that id is known
        if (!_component_ids.containsKey(new String(id))) {
            // either the id comes from a reference created by another POA, or the reference was removed
            // in both case, return null so that OBJECT_NOT_EXIST (or BAD_INV_ORDER ?) may be thrown
            final String msg = "FAILED (unknown id)";
            TheLogger.debug(_class_name, opname, msg);
            return null;
        }

        // create a new executor for this reference
        org.omg.Components.ExecutorSegmentBase cexe = null;
        CSAStorage storage = null;

        // get the component executor
        // try monolithic id
        MonolithicId mid = _midcodec.decode(id);
        if (mid!=null) {
            // NOTE: no class cast should occur
            storage = (CSAStorage)_id2home.get(new String(mid.home_id));
            org.omg.Components.HomeExecutor hexe = storage.home_executor;

            // check if a passivate executor exists
            cexe = lookupPassivated(id);

            if (cexe==null) {
                // create a new component executor
                cexe = hexe.create_component_segment(org.omg.Components.COMPONENT_ID.value);
            }
        }

        // try segmented if mid==null
        SegmentedId sid = null;
        if (mid==null) {
            // NOTE: sid can't be null
            sid = _sidcodec.decode(id);

            // NOTE: no class cast should occur
            storage = (CSAStorage)_id2home.get(new String(sid.home_id));
            org.omg.Components.HomeExecutor hexe = storage.home_executor;

            // check if a passivate executor exists
            cexe = lookupPassivated(id);

            if (cexe==null) {
                // create a new component executor
                cexe = hexe.create_component_segment(sid.segment_id);
            }
        }

        // check if it supports SessionComponent callback
        if (cexe instanceof org.omg.Components.SessionComponent) {
            org.omg.Components.SessionComponent scomp = (org.omg.Components.SessionComponent)cexe;
            org.omg.Components.SessionContext sessionctx = null;

            // find context
            if (mid!=null) {
                // NOTE: create a new context each time
                HomeSession2ContextImpl hctx = (HomeSession2ContextImpl)storage.ccm2context;
                Session2ContextImpl segctx = new Session2ContextImpl(hctx, mid.component_id);
                sessionctx = segctx;
            } else {
                // segmented case (use main segment id as key)
                org.omg.Components.SegmentDescr[] descrs = sid.segment_descrs;
                byte[] mainsegid = null;
                for (int i=0;i<descrs.length;i++) {
                    if (descrs[i].segment_id==org.omg.Components.COMPONENT_ID.value) {
                        mainsegid = descrs[i].object_id;
                        break;
                    }
                }

                // NOTE: create a new context each time
                HomeSegmentedSession2ContextImpl hctx = (HomeSegmentedSession2ContextImpl)storage.ccm2context;
                SegmentedSession2ContextImpl segctx = new SegmentedSession2ContextImpl(hctx, mainsegid);
                sessionctx = segctx;
            }

            try {
                scomp.set_session_context(sessionctx);
                scomp.ccm_activate();
            } catch (org.omg.Components.CCMException ex) {
                // NOTE: what can be done if activation fails ?
                TheLogger.debug(_class_name, opname, "FAILED", ex);
            }
        } else {
            // log
            final String msg = "IGNORE (SessionComponent not supported)";
            TheLogger.debug(_class_name, opname, msg);
        }

        // store
        _id2acomp.put(new String(id), cexe);

        // check if interceptors are available
        if (storage.interceptor_factory!=null) {
            org.omg.PortableServer.Servant poaserv = null;
            // check if monolithic or segmented
            CallInterceptorFactory ifact = storage.interceptor_factory;
            if (sid!=null) {
                poaserv = ifact.createSkeletonInterceptor(sid.segment_id, cexe);
            } else {
                poaserv = ifact.createSkeletonInterceptor(org.omg.Components.COMPONENT_ID.value, cexe);
            }

            return poaserv;
        } else {
            // log a message
            TheLogger.debug(_class_name, opname, "IGNORE (no interceptor factory)");
        }

        if (cexe instanceof org.omg.Components.Servant) {
            org.omg.Components.Servant servant = (org.omg.Components.Servant)cexe;
            return servant.as_native_servant();
        } else {
            TheLogger.error(_class_name, opname, "FAILED (not a CCM servant)");
            return null;
        }
    }

    // NOTE: no sychronisation required as the POA shall serialize
    // etherealization requests and incarnate/etherealize are mutually exclusive
    final public void
    etherealize(byte[] id,
                org.omg.PortableServer.POA poa,
                org.omg.PortableServer.Servant servant,
                boolean cleanup_in_progress,
                boolean remaining_activations)
    { 
        // check if removed
        final String opname = "etherealize";
        final boolean removed = _component_ids.containsKey(new String(id))? false : true;
        
        // NOTE: TODO: destroy the servant if it's a call interceptor

        // check if the delegate supports SessionComponent callback
        final Object obj = _id2acomp.remove(new String(id));

        if (obj instanceof org.omg.Components.SessionComponent) {
            org.omg.Components.SessionComponent scomp = (org.omg.Components.SessionComponent)obj;

            if (removed) {
                // NOTE: call callbacks: passivate and remove
                try {
                    // NOTE: no serialization/storage is needed
                    scomp.ccm_passivate();
                    scomp.ccm_remove();
                } catch (org.omg.Components.CCMException ex) {
                    // NOTE: what can be done if passivation/removal fails ?
                    TheLogger.debug(_class_name, opname, "FAILED", ex);
                }
            } else {
                // NOTE: passivate first and then serialize
                try {
                    scomp.ccm_passivate();
                } catch (org.omg.Components.CCMException ex) {
                    // NOTE: what can be done if passivation fails ?
                    TheLogger.debug(_class_name, opname, "FAILED", ex);
                }

                try {
                    final java.io.ByteArrayOutputStream bout=  new java.io.ByteArrayOutputStream();
                    final java.io.ObjectOutputStream oout = new java.io.ObjectOutputStream(bout);
                    oout.writeObject(scomp);
                    oout.flush();
                    bout.flush();
                    // get the sequence of bytes
                    final byte[] pcomp = bout.toByteArray();
                    oout.close();

                    // store
                    _id2pcomp.put(new String(id), new String(pcomp));
                } catch (Exception ex) {
                    // NOTE: what can be done if serialization fails ?
                    TheLogger.error(_class_name, opname, "FAILED", ex);
                }
            }
        } else {
            // log
            final String msg = "IGNORE (SessionComponent not supported)";
            TheLogger.debug(_class_name, opname, msg);
        }
    }
}

//
//
//
class CSAStorage
{
    // storage
    public org.omg.Components.HomeExecutor home_executor;
    public org.omg.Components.CCM2Context ccm2context;
    public CallInterceptorFactory interceptor_factory;

    // default constructor
    public
    CSAStorage(org.omg.Components.HomeExecutor hexe,
               org.omg.Components.CCM2Context ctx)
    {
        // storage
        home_executor = hexe;
        ccm2context = ctx;
        interceptor_factory = null;
    }

    // constructor with COPIs
    public
    CSAStorage(org.omg.Components.HomeExecutor hexe,
               org.omg.Components.CCM2Context ctx,
               CallInterceptorFactory ifact)
    {
        // storage
        home_executor = hexe;
        ccm2context = ctx;
        interceptor_factory = ifact;
    }
}

