// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Home specific implementation for the <tt>Components::Session2Context</tt> interface. This
 **  class implements the features which are common to all component instance in a particular
 **  home instance and is therefore provided to the home instances.</p>
 **/
public class HomeSegmentedSession2ContextImpl
extends org.omg.CORBA.LocalObject
implements org.omg.Components.SegmentedSession2Context, org.coach.ECM.ECMContext
{
    // segmented session context
    static private String _class_name = "SegmentedSession2ContextImpl";
    private org.omg.Components.CCMHome _home_ref;
    private ORBService _orb_service;
    private ComponentPOAService _poa_service;
    private ServicesSet _services_set;
    private HomeLocalEventsImpl _events;
    private HomeLocalReceptaclesImpl _receptacles;
    private SegmentedIdCodec _idcodec;

    // empty constructor
    protected
    HomeSegmentedSession2ContextImpl()
    {
        // segmented session context
        _home_ref = null;
        _orb_service = null;
        _poa_service = null;
        _services_set = null;
        _events = null;
        _receptacles = null;
        _idcodec = null;
    }

    // default constructor
    protected
    HomeSegmentedSession2ContextImpl(org.omg.Components.CCMHome href,
                                     ORBService orbs,
                                     ComponentPOAService poas,
                                     ServicesSet sset,
                                     HomeLocalEventsImpl levts,
                                     HomeLocalReceptaclesImpl lrecs)
    {
        // segmented session context
        _home_ref = href;
        _orb_service = orbs;
        _poa_service = poas;
        _services_set = sset;
        _events = levts;
        _receptacles = lrecs;

        // create ObjectId codec
        _idcodec = new SegmentedIdCodec(_orb_service);
    }

    //
    //  internal operations
    //

    private org.omg.PortableServer.Current
    getPOACurrent()
    {
        // get poa current
        org.omg.CORBA.Object curr = _orb_service.resolve_initial_references("POACurrent");
        return org.omg.PortableServer.CurrentHelper.narrow(curr);
    }

    //
    //  public operations (for component context)
    //

    final public HomeLocalEventsImpl
    getLocalEvents()
    {
        return _events;
    }

    final public HomeLocalReceptaclesImpl
    getLocalReceptacles()
    {
        return _receptacles;
    }

    //
    //  IDL:omg.org/Components/CCMContext:1.0
    //

    final public org.omg.Components.CCMHome
    get_CCM_home()
    {
        return _home_ref;
    }

    //
    //  IDL:omg.org/Components/CCM2Context:1.0
    //

    final public org.omg.Components.HomeRegistrationLocal
    get_home_registration()
    {
        // TODO 
        return null;
    }

    final public void
    req_passivate()
    throws org.omg.Components.IllegalState,
           org.omg.Components.PolicyMismatch
    {
        final String opname = "req_passivate";
        try {
            org.omg.PortableServer.Current curr = getPOACurrent();
            byte[] id = curr.get_object_id();
            _poa_service.passivate_component(id);
        } catch (org.omg.PortableServer.CurrentPackage.NoContext ex) {
            TheLogger.debug(_class_name, opname, "FAILED (no context, rethrown)", ex);
            throw new org.omg.Components.IllegalState();
        } catch (org.objectweb.ccm.runtime.WrongPolicy ex) {
            TheLogger.debug(_class_name, opname, "FAILED (wrong policy, rethrown)", ex);
            throw new org.omg.Components.PolicyMismatch();
        }
    }

    final public org.omg.Components.LocalEvents
    get_events()
    {
        // NOTE: not supported in home context implementation
        return null;
    }

    final public org.omg.Components.LocalReceptacles
    get_receptacles()
    {
        // NOTE: not supported in home context implementation
        return null;
    }

    final public void
    remove_component(org.omg.Components.CCMObject comp)
    {
        _poa_service.remove_component(comp);
    }

    final public void
    register_valuefactory(String repid, org.omg.CORBA.portable.ValueFactory vfact)
    {
        ValueFactory fact = new ValueFactoryImpl(repid, vfact);
        _orb_service.register_valuefactory(fact);
    }

    final public org.omg.CORBA.Any
    create_any()
    {
        return _orb_service.create_any();
    }

    //
    //  IDL:omg.org/Components/SessionContext:1.0
    //

    final public org.omg.CORBA.Object
    get_CCM_object()
    throws org.omg.Components.IllegalState
    {
        try {
            org.omg.PortableServer.Current curr = getPOACurrent();
            byte[] id = curr.get_object_id();
            org.omg.PortableServer.POA poa = curr.get_POA();

            return poa.id_to_reference(id);
        } catch (org.omg.PortableServer.CurrentPackage.NoContext exc) {
            throw new org.omg.Components.IllegalState();
        } catch (Exception ex) {
            // NOTE: should not happen
            final String opname = "get_CCM_object";
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        }
    }

    //
    //  IDL:omg.org/Components/SegmentedSession2Context:1.0
    //

    final public org.omg.Components.ComponentId
    get_component_id()
    throws org.omg.Components.IllegalState
    {
        try {
            return get_cid_from_ref(get_CCM_object());
        } catch (org.omg.Components.BadComponentReference ex) {
            // should not happen
            final String opname = "get_component_id";
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        }
    }

    final public org.omg.Components.ComponentId
    create_main_segment(org.omg.Components.SegmentDescr[] descrs)
    {
        return new ComponentIdImpl(org.omg.Components.COMPONENT_FACET.value,
                                   org.omg.Components.COMPONENT_ID.value,
                                   descrs);
    }

    final public org.omg.CORBA.Object
    create_ref_from_cid(String repid,
                        org.omg.Components.ComponentId cid)
    {
        final String opname = "create_ref_from_cid";

        // NOTE: the caller MUST be the home
        // NOTE2: obtain the object id of the home
        byte[] home_id = null;
        try {
            home_id = getPOACurrent().get_object_id();
        } catch (org.omg.PortableServer.CurrentPackage.NoContext exc) {
            // should not happen
            TheLogger.error(_class_name, opname, "FAILED (no context)", exc);
        }

        // create and encode oid
        SegmentedId sid = new SegmentedId();
        sid.home_id = home_id;
        sid.facet_id = cid.get_facet_id();
        sid.segment_id = cid.get_segment_id();
        sid.segment_descrs = cid.get_segment_descrs();
        byte[] rid = _idcodec.encode(sid);

        // create a ref
        return _poa_service.create_ref_with_id(rid, repid);
    }

    final public org.omg.Components.ComponentId
    get_cid_from_ref(org.omg.CORBA.Object ref)
    throws org.omg.Components.BadComponentReference
    {
        final String opname = "get_cid_from_ref";
        byte[] id = null;
        try {
            id = _poa_service.get_id_from_ref(ref);
        } catch (org.objectweb.ccm.runtime.InvalidReference ex) {
            // NOTE: to be completed with a reason
            TheLogger.debug(_class_name, opname, "FAILED (invalid ref, rethrown)", ex);
            throw new org.omg.Components.BadComponentReference();
        } 

        // decode
        SegmentedId sid = _idcodec.decode(id);
        if (sid==null) {
            // NOTE: to be completed with a reason
            TheLogger.debug(_class_name, opname, "FAILED (wrong format)");
            throw new org.omg.Components.BadComponentReference();
        }

        // create ComponentId
        return new ComponentIdImpl(sid.facet_id, sid.segment_id, sid.segment_descrs);
    }

    //
    //  IDL:coach.org/ECM/ECMContext:1.0
    //

    final public org.omg.CORBA.Object
    get_service_internal(String sid, String siid)
    throws org.coach.ECM.UnknownService,
           org.coach.ECM.UnknownServiceInternal
    {
        // find service
        Service service = _services_set.find_service(sid);
        if (service==null) {
            throw new org.coach.ECM.UnknownService();
        }

        // find internal
        org.omg.CORBA.Object internal = service.get_service_internal(siid);
        if (internal==null) {
            throw new org.coach.ECM.UnknownServiceInternal();
        }

        return internal;
    }
}
