// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>Simple implementation of client and server request interceptors which log
 **  debug messages.</p>
 **/
public class DebugORBInitializerImpl
extends org.omg.CORBA.LocalObject
implements org.omg.PortableInterceptor.ORBInitializer
{
    //
    static final private String _class_name = "DebugORBInitializerImpl";

    public
    DebugORBInitializerImpl()
    {
    }

    //
    //  IDL:omg.org/PortableInterceptor/ORBInitializer:1.0
    //

    final public void
    pre_init(org.omg.PortableInterceptor.ORBInitInfo info)
    {
        // only if debug is on
        String flag = System.getProperty("debug");
        if ((flag==null) || (!flag.equals("true"))) {
            return ;
        }

        String opname = "pre_init";
        TheLogger.debug(_class_name, opname, "");
        TheLogger.debug(_class_name, opname, "ORB id: "+info.orb_id());
        //String[] args = info.arguments();
        //for (int i=0;i<args.length;i++) {
        //    TheLogger.debug(_class_name, opname, "Arg #"+i+" "+args[i]);
        //}
    }

    final public void
    post_init(org.omg.PortableInterceptor.ORBInitInfo info)
    {
        // only if debug is on
        String flag = System.getProperty("debug");
        if ((flag==null) || (!flag.equals("true"))) {
            return ;
        }

        String opname = "post_init";
        TheLogger.debug(_class_name, opname, "");

        // register log CRI and SRI
        try {
            info.add_client_request_interceptor(new DebugCRIImpl());
            info.add_server_request_interceptor(new DebugSRIImpl());
        } catch (org.omg.PortableInterceptor.ORBInitInfoPackage.DuplicateName ex) {
            // ignore
            TheLogger.debug(_class_name, opname, "IGNORE (PI not registered)", ex);
        }
    }
}
