// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>Default implementation of the <tt>POAService</tt> system service.</p>
 **/
public class POAServiceImpl
extends org.omg.CORBA.LocalObject
implements POAService
{
    // poa service
    static final private String _class_name = "POAServiceImpl";
    static final private String _service_id = POAService.SERVICE_ID;
    private ORBService _orb_service;
    private org.omg.PortableServer.POA _poa;

    // default constructor
    public
    POAServiceImpl(org.omg.PortableServer.POA poa)
    {
        // poa service
        _orb_service = null;
        _poa = poa;
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        POAConfiguration poacfg = (POAConfiguration)cfg;
        _orb_service = poacfg.orb_service();
    }

    final public void
    destroy()
    {
        // destroy the POA
        // here, we have set:
        //   - 'etherealize_objects' param as true
        //   - 'wait_for_completion' param as true
        _poa.destroy(true, true);
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemService:1.0
    //

    final public String
    service_id()
    {
        return _service_id;
    }

    //
    //  IDL:objectweb.org/corba/runtime/POAService:1.0
    //

    final public void
    activate_servant_with_id(Servant serv, byte[] oid)
    {
        // create a native service
        org.omg.PortableServer.Servant nserv = null;
        nserv = serv.as_native_servant();

        // activate it on the wrapped POA
        try {
            _poa.activate_object_with_id(oid, nserv);
        } catch (Exception ex) {
            final String opname = "activate_servant_with_id";
            TheLogger.error(_class_name, opname, "FAILED", ex);
        }
    }

    final public void
    deactivate_servant(byte[] oid)
    {
        // deactivate servant on the wrapped POA
        try {
            _poa.deactivate_object(oid);
        } catch (Exception ex) {
            final String opname = "deactivate_servant";
            TheLogger.debug(_class_name, opname, "IGNORE", ex);
        }
    }

    final public org.omg.CORBA.Object
    create_ref(String repid)
    {
        // create a fake oid
        byte[] oid = Double.toString(Math.random()).getBytes();

        // create a ref
        return _poa.create_reference_with_id(oid, repid);
    }

    final public org.omg.CORBA.Object
    create_ref_with_id(byte[] oid, String repid)
    {
        // create a ref
        return _poa.create_reference_with_id(oid, repid);
    }

    final public byte[]
    get_id_from_ref(org.omg.CORBA.Object ref)
    {
        try {
            return _poa.reference_to_id(ref);
        } catch (Exception ex) {
            final String opname = "get_id_from_ref";
            TheLogger.error(_class_name, opname, "FAILED", ex);
            return null;
        } 
    }
}
