// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.logservice;

import org.objectweb.corba.runtime.*;
import org.objectweb.corba.logservice.*;

/**
 **  <p>Implementation of the <tt>LogInternal</tt> internal interface of the ECM log service.</p>
 **/
public class LogInternalImpl
extends org.omg.CORBA.LocalObject
implements LogInternal
{
    //
    private LogServer _server;

    public 
    LogInternalImpl(LogServer server)
    {
        _server = server;
    }

    //
    //  IDL:org/objectweb/ccm/logservice/LogInternal:1.0
    //

    final public void
    log_event(LogEvent evt)
    {
        new LogEventWorker(_server, evt).start();
    }

    final public void
    log_events(LogEvent[] evts)
    {
        new LogEventWorker(_server, evts).start();
    }
}

//
//  internal class used to send log events in separate threads
//
class LogEventWorker
extends java.lang.Thread
{
    //
    private LogServer _server;
    private LogEvent[] _events;

    public
    LogEventWorker(LogServer server,
                   LogEvent evt)
    {
        _server = server;
        _events = new LogEvent[1];
        _events[0] = evt;
    }

    public
    LogEventWorker(LogServer server,
                   LogEvent[] evts)
    {
        _server = server;
        _events = evts;
    }

    //
    //  java.lang.Thread
    //

    final public void
    run()
    {
        _server.log_events(_events);
    }
}
