// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.logservice;

import org.objectweb.corba.runtime.*;

/**
 **  <p>.</p>
 **/
public class LogServerImpl
extends org.omg.CORBA.LocalObject
implements Servant, LogServerOperations
{
    // system component
    static private String _class_name = "LogServerImpl";

    // servant
    static final private String _type_id =  LogServerHelper.id();

    // log server
    private javax.swing.JFrame _frame;
    private javax.swing.JTextArea _text_error;
    private javax.swing.JTextArea _text_warn;
    private javax.swing.JTextArea _text_info;
    private javax.swing.JTextArea _text_debug;

    // default constructor
    protected
    LogServerImpl()
    {
        // log server
        _frame = null;
        _text_error = null;
        _text_warn = null;
        _text_info = null;
        _text_debug = null;
    }

    //
    //  Entry point
    //

    static public Servant
    create_servant()
    {
        return new LogServerImpl();
    }

    //
    //  internal operations
    //

    private void
    initializeGUI()
    {
        // text areas for displaying events
        _text_error = new javax.swing.JTextArea(20, 25);
        _text_error.setEditable(false);
        javax.swing.JScrollPane scroll_err = new javax.swing.JScrollPane(_text_error);
        javax.swing.JLabel label_err = new javax.swing.JLabel("ERRORS");

        _text_warn = new javax.swing.JTextArea(20, 25);
        _text_warn.setEditable(false);
        javax.swing.JScrollPane scroll_warn = new javax.swing.JScrollPane(_text_warn);
        javax.swing.JLabel label_warn = new javax.swing.JLabel("WARNINGS");

        _text_info = new javax.swing.JTextArea(20, 25);
        _text_info.setEditable(false);
        javax.swing.JScrollPane scroll_info = new javax.swing.JScrollPane(_text_info);
        javax.swing.JLabel label_info = new javax.swing.JLabel("INFOS");

        _text_debug = new javax.swing.JTextArea(20, 25);
        _text_debug.setEditable(false);
        javax.swing.JScrollPane scroll_debug = new javax.swing.JScrollPane(_text_debug);
        javax.swing.JLabel label_debug = new javax.swing.JLabel("DEBUG");

        // boxes
        javax.swing.Box mbox = javax.swing.Box.createHorizontalBox();
        javax.swing.Box lbox = javax.swing.Box.createVerticalBox();
        //lbox.setSize(new java.awt.Dimension(250, 600));
        javax.swing.Box rbox = javax.swing.Box.createVerticalBox();
        //rbox.setSize(new java.awt.Dimension(250, 600));
        mbox.add(lbox);
        mbox.add(rbox);
        lbox.add(label_err);
        lbox.add(scroll_err);
        lbox.add(label_warn);
        lbox.add(scroll_warn);
        rbox.add(label_info);
        rbox.add(scroll_info);
        rbox.add(label_debug);
        rbox.add(scroll_debug);

        // frame
        _frame = new javax.swing.JFrame("LogServer GUI");
        _frame.getContentPane().add(mbox);
        _frame.pack();
        _frame.show();
    }

    //
    //  IDL:org/objectweb/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        //
        initializeGUI();
    }

    final public void
    destroy()
    {
        // TODO
    }

    //
    //  IDL:org/objectweb/corba/runtime/Servant:1.0
    //

    final public String
    type_id()
    {
        return _type_id;
    }

    final public org.omg.PortableServer.Servant
    as_native_servant()
    {
        return new LogServerPOATie(this);
    }

    //
    //  IDL:org/objectweb/corba/logservice/LogServer:1.0
    //

    final public void
    log_event(LogEvent evt)
    {
        javax.swing.JTextArea area = null;
        if (evt.level==org.objectweb.corba.logservice.ERROR_LEVEL.value) {
            area = _text_error;
        } else if (evt.level==org.objectweb.corba.logservice.WARN_LEVEL.value) {
            area = _text_warn;
        } else if (evt.level==org.objectweb.corba.logservice.INFO_LEVEL.value) {
            area = _text_info;
        } else if (evt.level==org.objectweb.corba.logservice.DEBUG_LEVEL.value) {
            area = _text_debug;
        }

        // System.err.println("### "+msg);

        area.append("[new message] \n");
        if (evt.message.interception_point.length()!=0) {
            area.append("    IP: "+evt.message.interception_point+"\n");
        }
        area.append("    timesptamp: "+evt.message.timestamp+"\n");
        area.append("    operation: "+evt.message.operation_name+"\n");
        if (evt.message.sender_id.length()!=0) {
            area.append("    sender: "+evt.message.sender_id+"\n");
        }
        if (evt.message.receiver_id.length()!=0) {
            area.append("    receiver: "+evt.message.receiver_id+"\n");
        }
        if (evt.message.data.length()!=0) {
            area.append("    data: "+evt.message.data+"\n");
        }
    }

    final public void
    log_events(LogEvent[] evts)
    {
        for (int i=0;i<evts.length;i++) {
            log_event(evts[i]);
        }
    }
}
